<h1 align = "center">:rocket: 效果可视化 :facepunch:</h1>

---
## [scikit-plot][1]
```
import scikitplot as skplt

skplt.metrics.plot_calibration_curve
skplt.metrics.plot_cumulative_gain
skplt.metrics.plot_ks_statistic
skplt.metrics.plot_lift_curve
skplt.metrics.plot_precision_recall
skplt.metrics.plot_roc
skplt.metrics.plot_silhouette # 聚类轮廓分析
skplt.cluster.plot_elbow_curve

skplt.classifiers.plot_confusion_matrix_with_cv
skplt.classifiers.plot_feature_importances
skplt.classifiers.plot_ks_statistic_with_cv
skplt.classifiers.plot_learning_curve
skplt.classifiers.plot_precision_recall_curve_with_cv
skplt.classifiers.plot_roc_curve_with_cv

skplt.decomposition.plot_pca_2d_projection
skplt.decomposition.plot_pca_component_variance
```
## [sklearn-evaluation][2]

---
[1]: https://github.com/reiinakano/scikit-plot
[2]: https://github.com/edublancas/sklearn-evaluation
